==> haskell-websockets-0.10.0.0-19-i686.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.10.0.0
id: websockets-0.10.0.0-4KOT6IJHR8dD7QNmtDgY1S
key: websockets-0.10.0.0-4KOT6IJHR8dD7QNmtDgY1S
license: BSD3
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2013 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
abi: e401998ccd43b4101f677837d0102964
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/websockets-0.10.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/websockets-0.10.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/websockets-0.10.0.0
hs-libraries: HSwebsockets-0.10.0.0-4KOT6IJHR8dD7QNmtDgY1S
depends:
    SHA-1.6.4.2-6ZuKopcglGG4yoCGsd9koJ
    attoparsec-0.13.1.0-DWdB5NAuEI54zL0UJYXwyo base-4.9.1.0
    base64-bytestring-1.0.0.1-4O9TExPPz6eI82Yj7L4SIj binary-0.8.3.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw containers-0.5.7.1
    entropy-0.3.8-14HIw40nRRY968j6AdY1H4
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    random-1.1-9tceXaeYIMZ4JrKq20Egog
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.10.0.0-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: websockets
version: 0.10.0.0
id: websockets-0.10.0.0-G5QaVEOGQM45nEjIvOTLgV
key: websockets-0.10.0.0-G5QaVEOGQM45nEjIvOTLgV
license: BSD3
copyright: (c) 2010-2011 Siniša Biđin
           (c) 2011-2013 Jasper Van der Jeugt
           (c) 2011 Steffen Schuldenzucker
           (c) 2011 Alex Lang
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: experimental
homepage: http://jaspervdj.be/websockets
synopsis: A sensible and clean way to write WebSocket-capable servers in Haskell.
description:
    This library allows you to write WebSocket-capable servers.
    .
    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>
    .
    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>
    .
    See also:
    .
    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>
    .
    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>
category: Network
author: Siniša Biđin <sinisa@bidin.cc>
        Jasper Van der Jeugt <m@jaspervdj.be>
        Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
        Alex Lang <lang@tsurucapital.com>
exposed: True
exposed-modules:
    Network.WebSockets Network.WebSockets.Connection
    Network.WebSockets.Stream
hidden-modules: Network.WebSockets.Client Network.WebSockets.Http
                Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
                Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
                Network.WebSockets.Server Network.WebSockets.Types
abi: 49d3023f6862338f1f055760e36b3e23
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/websockets-0.10.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/websockets-0.10.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/websockets-0.10.0.0
hs-libraries: HSwebsockets-0.10.0.0-G5QaVEOGQM45nEjIvOTLgV
depends:
    SHA-1.6.4.2-6ZuKopcglGG4yoCGsd9koJ
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    base64-bytestring-1.0.0.1-4O9TExPPz6eI82Yj7L4SIj binary-0.8.3.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw containers-0.5.7.1
    entropy-0.3.8-14HIw40nRRY968j6AdY1H4
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    random-1.1-9tceXaeYIMZ4JrKq20Egog
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html: /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
